@@ -249,7 +249,9 @@ def parse_scenario(data, num_players, version, save):
     map_id, difficulty_id = unpack('<II', data)
     remainder = data.read()
     if version is Version.DE:
-        if save >= 26.16:
+        if save >= 26.21:
+            settings_version = 3.2
+        elif save >= 26.16:
             settings_version = 3.0
         elif save >= 25.22:
             settings_version = 2.6
@@ -286,7 +288,9 @@ def parse_de(data, version, save, skip=False):
     data.read(dlc_count * 4)
     data.read(4)
     difficulty_id = unpack('<I', data)
-    data.read(20)
+    data.read(4)
+    rms_map_id = unpack('<I', data)
+    data.read(12)
     starting_age_id = unpack('<I', data)
     data.read(46)
     random_positions, all_technologies = unpack('<bb', data)
@@ -325,11 +329,16 @@ def parse_de(data, version, save, skip=False):
                 civilization_id=civilization_id,
                 prefer_random=prefer_random == 1
             ))
-    data.read(24)
+    data.read(17)
+    allow_specs = unpack('b', data)
+    visibility = unpack('<I', data)
+    hidden_civs = unpack('b', data)
+    data.read(1)
     spec_delay = unpack('<I', data)
     data.read(5)
+    strings = []
     for _ in range(23):
-        de_string(data)
+        strings.append(de_string(data).decode('utf-8').split(':'))
         c = unpack('<I', data)
         while c in [3, 21, 23, 42, 44, 45, 46, 47]:
             c = unpack('<I', data)
@@ -364,6 +373,12 @@ def parse_de(data, version, save, skip=False):
     if not skip:
         de_string(data)
         data.read(8)
+    rms_mod_id = None
+    rms_filename = None
+    for s in strings:
+        if s[0] == 'SUBSCRIBEDMODS' and s[1] == 'RANDOM_MAPS':
+            rms_mod_id = s[3].split('_')[0]
+            rms_filename = s[2]
     return dict(
         players=players,
         guid=str(uuid.UUID(bytes=guid)),
@@ -377,7 +392,13 @@ def parse_de(data, version, save, skip=False):
         lock_speed=bool(lock_speed),
         build=build,
         timestamp=timestamp,
-        spec_delay=spec_delay
+        spec_delay=spec_delay,
+        allow_specs=bool(allow_specs),
+        hidden_civs=bool(hidden_civs),
+        visibility_id=visibility,
+        rms_mod_id=rms_mod_id,
+        rms_map_id=rms_map_id,
+        rms_filename=rms_filename
     )
 
 
@@ -459,6 +480,10 @@ def parse_players(header, num_players, version):
     header.seek(cur + anchor - num_players - 43)
     mod = parse_mod(header, num_players, version)
     players = [parse_player(header, number, num_players) for number in range(num_players)]
+    cur = header.tell()
+    points_version = header.read().find(b'\x00\x00\x00@')
+    header.seek(cur)
+    header.read(points_version)
     for _ in range(num_players):
         version = unpack('<f', header)
         entries = unpack('<i', header)
@@ -494,8 +519,8 @@ def parse(data):
         players, mod = parse_players(header, num_players, version)
         scenario = parse_scenario(header, num_players, version, save)
         lobby = parse_lobby(header, version, save)
-    except (struct.error, zlib.error, AssertionError, MemoryError, ValueError):
-        raise RuntimeError("could not parse")
+    except (struct.error, zlib.error, AssertionError, MemoryError, ValueError) as e:
+        raise RuntimeError(f"could not parse: {e}")
     return dict(
         version=version,
         game_version=game,
