@@ -19,7 +19,33 @@ de_string = Struct(
 
 separator = Const(b"\xa3_\x02\x00")
 
+player = Struct(
+    "dlc_id"/Int32ul,
+    "color_id"/Int32sl,
+    "selected_color"/Byte,
+    "selected_team_id"/Byte,
+    "resolved_team_id"/Byte,
+    "dat_crc"/Bytes(8),
+    "mp_game_version"/Byte,
+    "civ_id"/Int32ul,
+    "ai_type"/de_string,
+    "ai_civ_name_index"/Byte,
+    "ai_name"/de_string,
+    "name"/de_string,
+    "type"/PlayerTypeEnum(Int32ul),
+    "profile_id"/Int32ul,
+    Const(b"\x00\x00\x00\x00"),
+    "player_number"/Int32sl,
+    "hd_rm_elo"/If(lambda ctx: find_save_version(ctx) < 25.22, Int32ul),
+    "hd_dm_elo"/If(lambda ctx: find_save_version(ctx) < 25.22, Int32ul),
+    "prefer_random"/Flag,
+    "custom_ai"/Flag,
+    If(lambda ctx: find_save_version(ctx) >= 25.06, "handicap"/Bytes(8)),
+)
+
 de = "de"/Struct(
+    "build"/If(lambda ctx: find_save_version(ctx) >= 25.22, Int32ul),
+    "timestamp"/If(lambda ctx: find_save_version(ctx) >= 26.16, Int32ul),
     "version"/Float32l,
     "interval_version"/Int32ul,
     "game_options_version"/Int32ul,
@@ -64,69 +90,59 @@ de = "de"/Struct(
     "turbo_enabled"/Flag,
     "shared_exploration"/Flag,
     "team_positions"/Flag,
-    If(lambda ctx: find_save_version(ctx) >= 13.34, Bytes(8)),
-    If(lambda ctx: find_save_version(ctx) >= 25.06, Bytes(1)),   # maybe handicap
+    "sub_game_mode"/If(lambda ctx: find_save_version(ctx) >= 13.34, Int32ul),
+    "battle_royale_time"/If(lambda ctx: find_save_version(ctx) >= 13.34, Int32ul),
+    "handicap"/If(lambda ctx: find_save_version(ctx) >= 25.06, Flag),
     separator,
-    "players"/Array(8, Struct(
-        "dlc_id"/Int32ul,
-        "color_id"/Int32sl,
-        "selected_color"/Byte,
-        "selected_team_id"/Byte,
-        "resolved_team_id"/Byte,
-        "dat_crc"/Bytes(8),
-        "mp_game_version"/Byte,
-        "civ_id"/Int32ul,
-        "ai_type"/de_string,
-        "ai_civ_name_index"/Byte,
-        "ai_name"/de_string,
-        "name"/de_string,
-        "type"/PlayerTypeEnum(Int32ul),
-        "profile_id"/Int32ul,
-        Const(b"\x00\x00\x00\x00"),
-        "player_number"/Int32sl,
-        "hd_rm_elo"/Int32ul,
-        "hd_dm_elo"/Int32ul,
-        "animated_destruction_enabled"/Flag,
-        "custom_ai"/Flag,
-        If(lambda ctx: find_save_version(ctx) >= 25.06, "unk"/Bytes(8)),  # maybe handicap related?
-    )),
+    "players"/Array(8, player),
+    Bytes(9),
     "fog_of_war"/Flag,
     "cheat_notifications"/Flag,
     "colored_chat"/Flag,
-    Bytes(9),
     separator,
-    Bytes(12),
-    If(lambda ctx: ctx._.save_version >= 13.13, Bytes(5)),
+    "ranked"/Flag,
+    "allow_specs"/Flag,
+    "lobby_visibility"/Int32ul,
+    "hidden_civs"/Flag,
+    "matchmaking"/Flag,
+    "spec_delay"/Int32ul,
+    "scenario_civ"/If(lambda ctx: find_save_version(ctx) >= 13.13, Byte),
+    "rms_crc"/If(lambda ctx: find_save_version(ctx) >= 13.13, Bytes(4)),
     "strings"/Array(23,
         Struct(
             "string"/de_string,
-            RepeatUntil(lambda x, lst, ctx: lst[-1] not in [3, 21, 23, 42, 44, 45, 46, 47], Int32ul)
+            "nums"/RepeatUntil(lambda x, lst, ctx: lst[-1] not in [3, 21, 23, 42, 44, 45, 46, 47], Int32ul)
         )
     ),
-    "strategic_numbers"/Array(59, Int32sl),
+    # There's probably a right way to do this, but this is not it.
+    "num_sn"/Computed(lambda ctx: ctx.strings[22].nums[1]),
+    "strategic_numbers"/Array(lambda ctx: ctx.num_sn if find_save_version(ctx) >= 25.22 else 59, Int32sl),
     "num_ai_files"/Int64ul,
     "ai_files"/Array(lambda ctx: ctx.num_ai_files, Struct(
         Bytes(4),
         "name"/de_string,
         Bytes(4),
     )),
-    If(lambda ctx: ctx._.save_version >= 25.02, Bytes(8)),
+    If(lambda ctx: find_save_version(ctx) >= 25.02, Bytes(8)),
     "guid"/Bytes(16),
     "lobby_name"/de_string,
+    If(lambda ctx: find_save_version(ctx) >= 25.22, Bytes(8)),
     "modded_dataset"/de_string,
     Bytes(19),
-    If(lambda ctx: ctx._.save_version >= 13.13, Bytes(5)),
-    If(lambda ctx: ctx._.save_version >= 13.17, Bytes(9)),
-    If(lambda ctx: ctx._.save_version >= 20.06, Bytes(1)),
-    If(lambda ctx: ctx._.save_version >= 20.16, Bytes(8)),
-    If(lambda ctx: ctx._.save_version >= 25.06, Bytes(21)),
+    If(lambda ctx: find_save_version(ctx) >= 13.13, Bytes(5)),
+    If(lambda ctx: find_save_version(ctx) >= 13.17, Bytes(9)),
+    If(lambda ctx: find_save_version(ctx) >= 20.06, Bytes(1)),
+    If(lambda ctx: find_save_version(ctx) >= 20.16, Bytes(8)),
+    If(lambda ctx: find_save_version(ctx) >= 25.06, Bytes(21)),
+    If(lambda ctx: find_save_version(ctx) >= 25.22, Bytes(4)),
+    If(lambda ctx: find_save_version(ctx) >= 26.16, Bytes(8)),
     de_string,
     Bytes(5),
-    If(lambda ctx: ctx._.save_version >= 13.13, Byte),
-    If(lambda ctx: ctx._.save_version < 13.17, Struct(
+    If(lambda ctx: find_save_version(ctx) >= 13.13, Byte),
+    If(lambda ctx: find_save_version(ctx) < 13.17, Struct(
         de_string,
         Int32ul,
         Bytes(4), # usually zero
     )),
-    If(lambda ctx: ctx._.save_version >= 13.17, Bytes(2))
+    If(lambda ctx: find_save_version(ctx) >= 13.17, Bytes(2)),
 )
