@@ -330,30 +330,30 @@ retarget = "retarget"/Struct(
 )
 
 unit_ai = "ai"/Struct(
-    "mood"/Int32ul,
-    "current_order"/Int32ul,
-    "current_order_priority"/Int32ul,
-    "current_action"/Int32ul,
-    "current_target"/Int32ul,
-    "current_target_type"/Int16ul,
+    "mood"/Int32sl,
+    "current_order"/Int32sl,
+    "current_order_priority"/Int32sl,
+    "current_action"/Int32sl,
+    "current_target"/Int32sl,
+    "current_target_type"/Int16sl,
     Padding(2),
     "current_target_location"/vector,
     "desired_target_distance"/Float32l,
-    "last_action"/Int32ul,
-    "last_order"/Int32ul,
-    "last_target"/Int32ul,
-    "last_target_type"/Int32ul,
-    "last_update_type"/Int32ul,
+    "last_action"/Int32sl,
+    "last_order"/Int32sl,
+    "last_target"/Int32sl,
+    "last_target_type"/Int32sl,
+    "last_update_type"/Int32sl,
     "idle_timer"/Int32ul,
     "idle_timeout"/Int32ul,
     "adjusted_idle_timeout"/Int32ul,
     "secondary_timer"/Int32ul,
     "look_around_timer"/Int32ul,
     "look_around_timeout"/Int32ul,
-    "defend_target"/Int32ul,
+    "defend_target"/Int32sl,
     "defense_buffer"/Float32l,
     "last_world_position"/waypoint,
-    "de_2006_unk"/If(lambda ctx: find_save_version(ctx) >= 20.06, Struct(
+    "de_2006_unk"/If(lambda ctx: 26.21 > find_save_version(ctx) >= 20.06, Struct(
         "unk_float"/Float32l,
         "unk"/Int32ul
     )),
@@ -369,7 +369,7 @@ unit_ai = "ai"/Struct(
     "state_position_y"/Float32l,
     "time_since_enemy_sighting"/Int32ul,
     "alert_mode"/Byte,
-    "alert_mode_object_id"/Int32ul,
+    "alert_mode_object_id"/Int32sl,
     "has_patrol_path"/Int32ul,
     If(lambda ctx: ctx.has_patrol_path > 0, path),
     "patrol_current_waypoint"/Int32ul,
@@ -379,7 +379,7 @@ unit_ai = "ai"/Struct(
     "randomized_retarget_timer"/Int32ul,
     "num_retarget_entries"/Int32ul,
     "retarget_entries"/Array(lambda ctx: ctx.num_retarget_entries, retarget),
-    "best_unit_to_attack"/Int32ul,
+    "best_unit_to_attack"/Int32sl,
     "formation_type"/Byte,
     "de_unk"/If(lambda ctx: find_version(ctx) == Version.DE, Bytes(4)),
     "de_unk_byte"/If(lambda ctx: find_save_version(ctx) >= 25.22, Byte)
