@@ -5,6 +5,22 @@ from mgz.util import Version
 from mgz.reference import get_dataset
 
 
+def resolve_hd_version(hd, save_version):
+    """Best guess at HD version."""
+    if hd.version == 1006:
+        if 'test_57' in hd and hd.test_57.is_57:
+            return '5.7'
+        else:
+            return '5.8'
+    if hd.version == 1005:
+        return '>=5.0,<5.7'
+    if hd.version == 1004:
+        return '4.8'
+    if save_version >= 12.36:
+        return '>=4.6,<4.8'
+    return None
+
+
 def get_dataset_data(header):
     """Get dataset."""
     sample = header.initial.players[0].attributes.player_stats
@@ -18,6 +34,12 @@ def get_dataset_data(header):
             'name': 'Definitive Edition',
             'version': None
         }, ref
+    elif header.version == Version.HD:
+        return {
+            'id': 300,
+            'name': 'HD Edition',
+            'version': resolve_hd_version(header.hd, header.save_version)
+        }, ref
     if 'mod' in sample and sample.mod['id'] == 0 and sample.mod['version'] == '2':
         raise ValueError("invalid mod version")
     if 'mod' in sample and sample.mod['id'] > 0:
